.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.


Power functions
===============

**xtensor** provides the following power functions for xexpressions and scalars:

Defined in ``xtensor/xmath.hpp``

.. _pow-function-reference:
.. doxygenfunction:: pow(E1&&, E2&&)
   :project: xtensor

.. doxygenfunction:: pow(E&&)
   :project: xtensor

.. doxygenfunction:: square(E1&&)
   :project: xtensor

.. doxygenfunction:: cube(E1&&)
   :project: xtensor

.. _sqrt-function-reference:
.. doxygenfunction:: sqrt(E&&)
   :project: xtensor

.. _cbrt-function-reference:
.. doxygenfunction:: cbrt(E&&)
   :project: xtensor

.. _hypot-func-ref:
.. doxygenfunction:: hypot(E1&&, E2&&)
   :project: xtensor

